import GPIO from "rpi-gpio";
import Container from "./database/Container";
import {IContainer} from "./database/IContainer";

export class MyGPIO {
    static setup(pin: number, direction): Promise<void> {
        return new Promise((resolve, reject) => {
            GPIO.setup(pin, direction, (err) => {
                if (err) {
                    reject();
                    return;
                }
                resolve();
            });
        })
    }

    static write(pin: number, state: boolean): Promise<void> {
        return new Promise((resolve, reject) => {
            GPIO.write(pin, state, (err) => {
                if (err) {
                    reject();
                    return;
                }
                resolve();
            });
        });
    }

    static setupPins() : Promise<void> {
        return new Promise(async resolve => {
            let containers = await Container.find({}) as IContainer[];
            for (let c of containers) {
                if (c.sensorType) {
                    await MyGPIO.setup(c.sensorPin1, GPIO.DIR_IN);
                    await MyGPIO.setup(c.sensorPin2, GPIO.DIR_IN);
                }
                await MyGPIO.setup(c.pumpPin, GPIO.DIR_OUT);
                await MyGPIO.write(c.pumpPin, false);
            }
            resolve();
        });
    }
}